@@ -1,8 +1,11 @@
 """Exceptions and error representations."""
+from __future__ import annotations
+
 import functools
-from typing import Any, Dict, List, Optional, Union
+from typing import Any
 
 from ansiblelint._internal.rules import BaseRule, RuntimeErrorRule
+from ansiblelint.config import options
 from ansiblelint.file_utils import Lintable, normpath
 
 
@@ -18,6 +21,8 @@ class MatchError(ValueError):
     instance.
     """
 
+    tag = ""
+
     # IMPORTANT: any additional comparison protocol methods must return
     # IMPORTANT: `NotImplemented` singleton to allow the check to use the
     # IMPORTANT: other object's fallbacks.
@@ -26,15 +31,15 @@ class MatchError(ValueError):
     # pylint: disable=too-many-arguments
     def __init__(
         self,
-        message: Optional[str] = None,
+        message: str | None = None,
         # most linters report use (1,1) base, including yamllint and flake8
         # we should never report line 0 or column 0 in output.
         linenumber: int = 1,
-        column: Optional[int] = None,
+        column: int | None = None,
         details: str = "",
-        filename: Optional[Union[str, Lintable]] = None,
+        filename: Lintable | None = None,
         rule: BaseRule = RuntimeErrorRule(),
-        tag: Optional[str] = None,  # optional fine-graded tag
+        tag: str | None = None,  # optional fine-graded tag
     ) -> None:
         """Initialize a MatchError instance."""
         super().__init__(message)
@@ -63,21 +68,32 @@ class MatchError(ValueError):
         self.filename = ""
         if filename:
             if isinstance(filename, Lintable):
+                self.lintable = filename
                 self.filename = normpath(str(filename.path))
             else:
                 self.filename = normpath(filename)
+                self.lintable = Lintable(self.filename)
         self.rule = rule
         self.ignored = False  # If set it will be displayed but not counted as failure
         # This can be used by rules that can report multiple errors type, so
         # we can still filter by them.
-        self.tag = tag
+        self.tag = tag or rule.id
 
         # optional indicator on how this error was found
-        self.match_type: Optional[str] = None
+        self.match_type: str | None = None
         # for task matches, save the normalized task object (useful for transforms)
-        self.task: Optional[Dict[str, Any]] = None
+        self.task: dict[str, Any] | None = None
         # path to the problem area, like: [0,"pre_tasks",3] for [0].pre_tasks[3]
-        self.yaml_path: List[Union[int, str]] = []
+        self.yaml_path: list[int | str] = []
+        # True when a transform has resolved this MatchError
+        self.fixed = False
+
+    @functools.cached_property
+    def level(self) -> str:
+        """Return the level of the rule: error, warning or notice."""
+        if {self.tag, self.rule.id, *self.rule.tags}.isdisjoint(options.warn_list):
+            return "error"
+        return "warning"
 
     def __repr__(self) -> str:
         """Return a MatchError instance representation."""
