@@ -1,7 +1,8 @@
 """Tests related to skip tag id."""
 from ansiblelint.rules import RulesCollection
-from ansiblelint.rules.yaml import YamllintRule
+from ansiblelint.rules.yaml_rule import YamllintRule
 from ansiblelint.runner import Runner
+from ansiblelint.testing import run_ansible_lint
 
 FILE = "examples/playbooks/with-skip-tag-id.yml"
 collection = RulesCollection()
@@ -20,7 +21,7 @@ def test_negative_with_id() -> None:
     with_id = "yaml"
     bad_runner = Runner(FILE, rules=collection, tags=frozenset([with_id]))
     errs = bad_runner.run()
-    assert len(errs) > 0
+    assert len(errs) == 1
 
 
 def test_negative_with_tag() -> None:
@@ -28,7 +29,7 @@ def test_negative_with_tag() -> None:
     with_tag = "trailing-spaces"
     bad_runner = Runner(FILE, rules=collection, tags=frozenset([with_tag]))
     errs = bad_runner.run()
-    assert len(errs) > 0
+    assert len(errs) == 1
 
 
 def test_positive_skip_id() -> None:
@@ -40,6 +41,18 @@ def test_positive_skip_id() -> None:
 
 def test_positive_skip_tag() -> None:
     """Positive test skip_tag."""
-    skip_tag = "trailing-spaces"
+    skip_tag = "yaml[trailing-spaces]"
     good_runner = Runner(FILE, rules=collection, skip_list=[skip_tag])
     assert [] == good_runner.run()
+
+
+def test_run_skip_warning_rule() -> None:
+    """Test that we can skip warning[empty-playbook]."""
+    result = run_ansible_lint(
+        "-x",
+        "warning[empty-playbook]",
+        "examples/playbooks/empty_playbook.yml",
+        executable="ansible-lint",
+    )
+    assert result.returncode == 0
+    assert result.stdout == ""
